@@ -690,10 +690,19 @@ def Reconstruct_scST(adata_ref, adata_query, n_neighbors=1000,
     dis_sc[neighbors_sc >= n_ST] = 1e6
     dis_sc[:, 0] = 1e6
     adata_query.obs['Dis2ClosestBead'] = dis_sc.min(axis=1)
+
+    #Label closest ST beads of single cells
     adata_query.obs['ClosestBead_order'] = neighbors_sc[range(neighbors_sc.shape[0]),
     dis_sc.argmin(axis=1)]
     adata_query.obs['ClosestBead_name'] = adata_ref.obs_names[adata_query.obs['ClosestBead_order']]
 
+    #Label closest single cells of ST beads
+    # ClosestSC_list = adata_query.groupby('ClosestBead_name', as_index = False)['Dis2ClosestBead'].idxmin()['Dis2ClosestBead'].tolist()
+    ClosestSC_list = adata_query.obs.reset_index().groupby('ClosestBead_name', as_index=False).agg(
+        {'Dis2ClosestBead': 'min', 'index': 'first'})['index'].tolist()
+    adata_query.obs['ClosestSC'] = False
+    adata_query.obs.loc[ClosestSC_list, 'ClosestSC'] = True
+
     adata_query.obs['Recon_scST'] = False
     adata_query.obs['Recon_scST_layer'] = -1
     for layer, n_cell in enumerate(n_layer_cell):
